%global reltag rc5
%global namedreltag -%{?reltag}
%global namedversion %{version}%{?namedreltag}

%define with_ant 0
%define with_gradle 0
%define with_maven 1

Name:          jcsp
Version:       1.1
Release:       %mkrel 1.rc5.1
Summary:       Communicating Sequential Processes for Java (JCSP)
Group:         Development/Java
License:       LGPL
Url:           http://xircles.codehaus.org/projects/jcsp
# mkdir jcsp-1.1-rc5
# git clone git://git.codehaus.org/jcsp.git
# cd jcsp
# git archive 1.1-rc5 | tar -x -C ../jcsp-1.1-rc5
# cd ..
# tar czf jcsp-1.1-rc5-src-git.tar.gz jcsp-1.1-rc5
Source0:       jcsp-%{namedversion}-src-git.tar.gz
Patch0:        jcsp-1.1-ant-contrib.patch
# remove wagon-webdav
# update rat plugin group and artifact ID
Patch1:        jcsp-1.1-rc5-pom.patch
BuildRequires: java-devel
BuildRequires: jpackage-utils

%if %with_ant
BuildRequires: ant
BuildRequires: ant-contrib
%endif

%if %with_gradle
BuildRequires: gradle
BuildRequires: junit4
%endif

%if %with_maven
BuildRequires: felix-osgi-core
BuildRequires: junit4

BuildRequires: apache-rat-plugin
BuildRequires: findbugs-maven-plugin
BuildRequires: jdepend-maven-plugin
BuildRequires: maven
BuildRequires: maven-compiler-plugin
BuildRequires: maven-javadoc-plugin
BuildRequires: maven-plugin-bundle
BuildRequires: maven-plugin-cobertura
BuildRequires: maven-plugin-jxr
BuildRequires: maven-pmd-plugin
BuildRequires: maven-surefire-report-plugin
BuildRequires: taglist-maven-plugin
BuildRequires: forge-parent
BuildRequires: maven-shared-osgi
BuildRequires: maven-surefire-provider-junit4
Requires:      felix-osgi-core
%endif

Requires:      java
Requires:      jpackage-utils
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
BuildArch:     noarch

%description
JCSP (Communication Sequential Processes for Java) is a
library providing a concurrency model that is a combination
of ideas from Hoare's CSP and Milner's pi-calculus.

Communicating Sequential Processes (CSP) is a mathematical
theory for specifying and verifying complex patterns of
behaviour arising from interactions between concurrent
objects.

JSCP provides a base range of CSP primitives plus a rich set of
extensions. Also included is a package providing CSP process
wrappers giving a channel interface to all Java AWT widgets
and graphics operations.  It is extensively (javadoc)umented
and includes much teaching.

JCSP is an alternative concurrency model to the threads and
mechanisms built into Java. It is also compatible with
it since it is implemented on top of it.

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%{_javadir}/%{name}.jar
%{_mavenpomdir}/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}
%if %with_ant
%{_javadir}/%{name}-core.jar
%{_javadir}/%{name}-demos-util.jar
%doc dist/jcsp-%{namedversion}/GNU-LGPL-2.1.txt dist/jcsp-%{namedversion}/README-JCSP-%{namedversion}.txt
%else
%doc LICENCE.txt README.txt
%endif

#--------------------------------------------------------------------

%package javadoc
Group:         Development/Java
Summary:       Javadoc for %{name}
Requires:      jpackage-utils

%description javadoc
This package contains javadoc for %{name}.

%files javadoc
%{_javadocdir}/%{name}

#--------------------------------------------------------------------

%prep
%setup -q -n jcsp-%{namedversion}

find \( -name '*.jar' -o -name '*.class' \) -exec rm -f '{}' \;

sed -i "s|rc4|%{?reltag}|" README.txt

for d in LICENCE README ; do
  iconv -f iso8859-1 -t utf-8 $d.txt > $d.txt.conv && mv -f $d.txt.conv $d.txt
  sed -i 's/\r//' $d.txt
done

%if %with_ant
%patch0 -p0
sed -i "s|1.1-rc4|%{namedversion}|" build.xml
%endif
%if %with_maven
# prevent javadoc build failure
rm -r src/jcsp-demos
rm -r src/org/jcsp/test
sed -i "s|<excludePackageNames>jcsp-demos.*,org.jcsp.test.*</excludePackageNames>|<!--excludePackageNames>jcsp-demos.*,org.jcsp.test.*</excludePackageNames-->|" pom.xml
%endif
%patch1 -p0

rm JCSP\ Networking.pdf

%build

%if %with_ant
  %ant all
%endif
%if %with_gradle
  export GRADLE_USER_HOME=$PWD
  mkdir -p gradlehome
  gradle jar javadoc -g $PWD/gradlehome -b $PWD/build.gradle
%endif
%if %with_maven
  mvn-rpmbuild \
    install javadoc:aggregate
%endif

%install
rm -rf %{buildroot}

mkdir -p %{buildroot}%{_javadir}
mkdir -p %{buildroot}%{_javadocdir}/%{name}

%if %with_ant
  install -pm 644 dist/%{name}-%{namedversion}/%{name}-core.jar %{buildroot}%{_javadir}/%{name}-core.jar
  install -pm 644 dist/%{name}-%{namedversion}/%{name}-demos-util.jar %{buildroot}%{_javadir}/%{name}-demos-util.jar
  install -pm 644 dist/%{name}-%{namedversion}/%{name}.jar %{buildroot}%{_javadir}/%{name}.jar
  cp -a  dist/%{name}-%{namedversion}/%{name}-core-doc %{buildroot}%{_javadocdir}/%{name}/core
  cp -pr dist/%{name}-%{namedversion}/%{name}-doc/* %{buildroot}%{_javadocdir}/%{name}/
%endif

%if %with_gradle
  install -pm 644 build/libs/%{name}-%{namedversion}.jar %{buildroot}%{_javadir}/%{name}.jar
  cp -pr build/docs/javadoc/* %{buildroot}%{_javadocdir}/%{name}/
%endif

%if %with_maven
  install -pm 644 target/%{name}-%{namedversion}.jar %{buildroot}%{_javadir}/%{name}.jar
  cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%endif

mkdir -p %{buildroot}%{_mavenpomdir}
install -pm 644 pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap JPP-%{name}.pom %{name}.jar



%changelog

* Thu Jan 12 2012 gil <gil> 1.1-1.rc5.1.mga2
+ Revision: 195223
- fix BR
- fix BR
- imported package jcsp

